@@ -178,7 +178,8 @@ MAX-ID is a flag to include the max_id pagination parameter."
   (map-keys mastodon-profile--account-view-alist))
 
 (defun mastodon-profile--account-view-cycle (&optional prefix)
-  "Cycle through profile view: toots, toot sans boosts, followers, and following."
+  "Cycle through profile view: toots, toot sans boosts, followers, and following.
+If a PREFIX argument is provided, prompt for a view type and load."
   (interactive "P")
   (if prefix
       (let* ((choice
@@ -335,7 +336,7 @@ If value is :json-false, return nil."
                                      'display nil)
                          "/500 characters")
                         'read-only t
-                        'face 'font-lock-comment-face
+                        'face 'mastodon-toot-docs-face
                         'note-header t)
             "\n")
     (make-local-variable 'after-change-functions)
@@ -729,25 +730,25 @@ MAX-ID is a flag to include the max_id pagination parameter."
                  ;; sharkey has no relationships endpoint, returns 500.
                  ;; or poss it has a different endpoint
                  ""
-                 (let* ((followsp (mastodon-profile--follows-p
-                                   (list .requested_by .following .followed_by)))
-                        (rels (mastodon-profile--relationships-get .id))
-                        (langs-filtered (if-let ((langs (alist-get 'languages rels)))
-                                            (concat " ("
-                                                    (mapconcat #'identity langs " ")
-                                                    ")")
-                                          "")))
-                   (if followsp
-                       (mastodon-tl--set-face
-                        (concat (when (eq .following t)
-                                  (format " | FOLLOWED BY YOU%s" langs-filtered))
-                                (when (eq .followed_by t)
-                                  " | FOLLOWS YOU")
-                                (when (eq .requested_by t)
-                                  " | REQUESTED TO FOLLOW YOU")
-                                "\n\n")
-                        'success)
-                     ""))))) ; for insert call
+               (let* ((followsp (mastodon-profile--follows-p
+                                 (list .requested_by .following .followed_by)))
+                      (rels (mastodon-profile--relationships-get .id))
+                      (langs-filtered (if-let* ((langs (alist-get 'languages rels)))
+                                          (concat " ("
+                                                  (mapconcat #'identity langs " ")
+                                                  ")")
+                                        "")))
+                 (if followsp
+                     (mastodon-tl--set-face
+                      (concat (when (eq .following t)
+                                (format " | FOLLOWED BY YOU%s" langs-filtered))
+                              (when (eq .followed_by t)
+                                " | FOLLOWS YOU")
+                              (when (eq .requested_by t)
+                                " | REQUESTED TO FOLLOW YOU")
+                              "\n\n")
+                      'success)
+                   ""))))) ; for insert call
           (mastodon-media--inline-images (point-min) (point))
           ;; widget items description
           (mastodon-widget--create
